@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Lite;
 
-our $DATE = '2015-01-14'; # DATE
-our $VERSION = '0.78'; # VERSION
+our $DATE = '2015-01-15'; # DATE
+our $VERSION = '0.79'; # VERSION
 
 use 5.010001;
 # use strict; # already enabled by Mo
@@ -328,15 +328,15 @@ sub run_help {
     my $has_sc_no_sc = $self->subcommands && !length($r->{subcommand_name});
     delete $common_opts->{subcommands} if $self->subcommands && !$has_sc_no_sc;
 
-    my $meta   = $has_sc_no_sc ? {v=>1.1} :
-        $self->get_meta($r, $scd->{url} // $self->{url});
+    my $meta = $self->get_meta($r, $scd->{url} // $self->{url});
 
     my $res = Perinci::CmdLine::Help::gen_help(
         program_name => $self->get_program_and_subcommand_name($r),
-        program_summary => $scd ? $scd->{summary} : undef,
+        program_summary => ($scd ? $scd->{summary}:undef ) // $meta->{summary},
         program_description => $scd ? $scd->{description} : undef,
         meta => $meta,
-        common_opts => $self->common_opts,
+        subcommands => $has_sc_no_sc ? $self->subcommands : undef,
+        common_opts => $common_opts,
         per_arg_json => $self->per_arg_json,
         per_arg_yaml => $self->per_arg_yaml,
     );
@@ -382,7 +382,7 @@ Perinci::CmdLine::Lite - A lightweight Rinci/Riap-based command-line application
 
 =head1 VERSION
 
-This document describes version 0.78 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2015-01-14.
+This document describes version 0.79 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2015-01-15.
 
 =head1 SYNOPSIS
 
